=================
OpenStack Neutron
=================

.. image:: https://governance.openstack.org/tc/badges/neutron.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

Neutron is an OpenStack project to provide "network connectivity as a service"
between interface devices (e.g., vNICs) managed by other OpenStack services
(e.g., Nova).

To learn more about neutron:

  * Documentation: https://docs.openstack.org/neutron/latest/
  * Features: https://specs.openstack.org/openstack/neutron-specs
  * Defects: https://launchpad.net/neutron
  * Release notes: https://docs.openstack.org/releasenotes/neutron/index.html
  * Source: https://opendev.org/openstack/neutron

If you would like to contribute to Neutron, please read the file
`CONTRIBUTING.rst <CONTRIBUTING.rst>`__ or see the Neutron contributor guide:

    https://docs.openstack.org/neutron/latest/contributor/contributing.html

Get in touch via `email <mailto:openstack-discuss@lists.openstack.org>`_. Use
[Neutron] in your subject.
